@@ -137,22 +137,24 @@ class KISOverseasStock:
         output1['zdiv'] = int(output1['zdiv'])
         output2 = []
         for data in body['output2']:
-            output2.append({
-                'xymd': dtm.datetime.strptime(data['xymd'], '%Y%m%d').date(), # 일자
-                'clos': Decimal(data['clos']), # 종가
-                'sign': int(data['sign']), # 대비기호 - 1:상한 2:상승 3:보합 4:하한 5:하락
-                'diff': Decimal(data['diff']), # 대비 - 전일 종가와 당일 현재가의 차이 (당일 현재가 - 전일 종가)
-                'rate': Decimal(data['rate']), # 등락율 = 전일 대비 / 당일 현재가 * 100
-                'open': Decimal(data['open']), # 시가
-                'high': Decimal(data['high']), # 고가
-                'low': Decimal(data['low']), # 저가
-                'tvol': int(data['tvol']), # 거래량
-                'tamt': int(data['tamt']), # 거래대금
-                'pbid': Decimal(data['pbid']), # 매수호가
-                'vbid': int(data['vbid']), # 매수잔량
-                'pask': Decimal(data['pask']), # 매도호가
-                'vask': int(data['vask']), # 매도잔량
-            })
+            output2.append(
+                {
+                    "xymd": dtm.datetime.strptime(data["xymd"], "%Y%m%d").date(),  # 일자
+                    "clos": Decimal(data["clos"]),  # 종가
+                    "sign": int(data["sign"]),  # 대비기호 - 1:상한 2:상승 3:보합 4:하한 5:하락
+                    "diff": Decimal(data["diff"]),  # 대비 - 전일 종가와 당일 현재가의 차이 (당일 현재가 - 전일 종가)
+                    "rate": Decimal(data["rate"]),  # 등락율 = 전일 대비 / 당일 현재가 * 100
+                    "open": Decimal(data["open"]),  # 시가
+                    "high": Decimal(data["high"]),  # 고가
+                    "low": Decimal(data["low"]),  # 저가
+                    "tvol": int(data["tvol"]),  # 거래량
+                    "tamt": Decimal(data["tamt"]),  # 거래대금
+                    "pbid": Decimal(data["pbid"]),  # 매수호가
+                    "vbid": int(data["vbid"]),  # 매수잔량
+                    "pask": Decimal(data["pask"]),  # 매도호가
+                    "vask": int(data["vask"]),  # 매도잔량
+                }
+            )
 
         return {
             'tr_id': header['tr_id'],
