@@ -5,7 +5,7 @@ from pyqqq.data.realtime import get_all_last_trades
 from pyqqq.datatypes import *
 from pyqqq.utils.market_schedule import get_market_schedule
 from pyqqq.utils.mock_api import with_mock
-from typing import AsyncGenerator, List, Optional
+from typing import AsyncGenerator, Dict, List, Optional
 import asyncio
 import datetime as dtm
 import pandas as pd
@@ -31,6 +31,7 @@ class KISSimpleDomesticStock:
         account_no (str): 계좌 번호
         account_product_code (str): 계좌 상품 코드
         hts_id (Optional[str]): HTS ID
+        corp_data (Optional[dict]): 기업 고객의 경우 추가로 필요한 정보를 담고 있는 객체
     """
 
     def __init__(
@@ -39,11 +40,12 @@ class KISSimpleDomesticStock:
         account_no: str,
         account_product_code: str,
         hts_id: Optional[str] = None,
+        corp_data: Optional[dict] = None,
     ):
 
         self.account_no = account_no
         self.account_product_code = account_product_code
-        self.stock_api = KISDomesticStock(auth)
+        self.stock_api = KISDomesticStock(auth, corp_data)
         self.hts_id = hts_id
 
     def get_account(self) -> dict:
@@ -185,7 +187,7 @@ class KISSimpleDomesticStock:
 
         return result
 
-    def get_historical_daily_data(self, asset_code: str, first_date: dtm.date, last_date: dtm.date, adjusted_price: bool = False) -> pd.DataFrame:
+    def get_historical_daily_data(self, asset_code: str, first_date: dtm.date, last_date: dtm.date, adjusted_price: bool = True) -> pd.DataFrame:
         """
         일봉 데이터 검색
 
@@ -932,3 +934,44 @@ class KISSimpleDomesticStock:
             filled_time,
             org_order_no,
         )
+
+    def get_orderbook(self, asset_code: str) -> Dict:
+        """
+        특정 종목의 호가/잔량 정보를 조회하여 반환합니다.
+
+        Args:
+            asset_code (str): 조회할 자산의 종목번호.
+
+        Returns:
+            dict: 호가 정보가 포함된 사전.
+                - total_bid_volume (int): 총 매수 잔량.
+                - total_ask_volume (int): 총 매도 잔량.
+                - ask_price (int): 1차 매도 호가 가격.
+                - ask_volume (int): 1차 매도 호가 잔량.
+                - bid_price (int): 1차 매수 호가 가격.
+                - bid_volume (int): 1차 매수 호가 잔량.
+                - time (dtm.datetime): 현지 기준 호가 정보 조회 시간.
+                - bids (list): 매수 호가 목록 (각 항목은 price와 volume을 포함하는 dict).
+                - asks (list): 매도 호가 목록 (각 항목은 price과 volume을 포함하는 dict).
+
+        Raises:
+            ValueError: 주어진 티커가 유효하지 않거나 찾을 수 없는 경우 발생.
+        """
+
+        r = self.stock_api.inquire_asking_price_exp_ccn(asset_code)
+
+        o1 = r["output1"]
+
+        result = {
+            "total_bid_volume": o1["total_bidp_rsqn"],
+            "total_ask_volume": o1["total_askp_rsqn"],
+            "ask_price": o1["askp1"],
+            "ask_volume": o1["askp_rsqn1"],
+            "bid_price": o1["bidp1"],
+            "bid_volume": o1["bidp_rsqn1"],
+            "time": dtm.datetime.combine(dtm.date.today(), o1["aspr_acpt_hour"]),
+            "bids": [{"price": o1[f"bidp{i}"], "volume": o1[f"bidp_rsqn{i}"]} for i in range(1, 11)],
+            "asks": [{"price": o1[f"askp{i}"], "volume": o1[f"askp_rsqn{i}"]} for i in range(1, 11)],
+        }
+
+        return result
