@@ -7,6 +7,7 @@ from pyqqq.datatypes import *
 from pyqqq.utils.limiter import CallLimiter
 from pyqqq.utils.local_cache import ttl_cache
 from typing import Dict, List, Optional
+from zoneinfo import ZoneInfo
 import datetime as dtm
 import pandas as pd
 
@@ -29,6 +30,9 @@ class KISSimpleOverseasStock:
         hts_id (Optional[str]): HTS ID (해외주식 계좌 식별자).
     """
 
+    nyt = ZoneInfo("America/New_York")
+    kst = ZoneInfo("Asia/Seoul")
+
     def __init__(
         self,
         auth: KISAuth,
@@ -264,7 +268,7 @@ class KISSimpleOverseasStock:
             ]
             return result
 
-    def get_historical_daily_data(
+    def get_historical_daily_data_old(
         self,
         ticker: str,
         first_date: dtm.date,
@@ -276,8 +280,8 @@ class KISSimpleOverseasStock:
 
         Args:
             ticker (str): 조회할 자산의 티커(symbol).
-            first_date (datetime.date): 조회를 시작할 첫 번째 날짜 (YYYY-MM-DD).
-            last_date (datetime.date): 조회를 마칠 마지막 날짜 (YYYY-MM-DD).
+            first_date (datetime.date): 조회를 시작할 첫 번째 날짜 (YYYY-MM-DD). 현지기준 일자.
+            last_date (datetime.date): 조회를 마칠 마지막 날짜 (YYYY-MM-DD). 현지 기준 일자.
             period (str, optional): 조회할 데이터의 주기, 기본값은 "D" (일간).
 
         Returns:
@@ -340,6 +344,98 @@ class KISSimpleOverseasStock:
 
         return pd.DataFrame(rows).set_index("date")
 
+    def get_historical_daily_data(
+        self,
+        ticker: str,
+        first_date: dtm.date,
+        last_date: dtm.date,
+        period: str = "D",
+        adjusted: bool = True,
+    ) -> pd.DataFrame:
+        """
+        특정 티커의 일간 데이터를 조회하여 데이터프레임으로 반환합니다.
+
+        Args:
+            ticker (str): 조회할 자산의 티커(symbol).
+            first_date (datetime.date): 조회를 시작할 첫 번째 날짜 (YYYY-MM-DD). 현지기준 일자.
+            last_date (datetime.date): 조회를 마칠 마지막 날짜 (YYYY-MM-DD). 현지 기준 일자.
+            period (str, optional): 조회할 데이터의 주기, 기본값은 "D" (일간).
+            adjusted (bool, optional): 수정 종가를 사용할지 여부, 기본값은 True.
+
+        Returns:
+            pd.DataFrame: 조회된 일간 데이터가 포함된 Pandas DataFrame.
+                - date (index): 일자 (YYYY-MM-DD 형식).
+                - open (float): 시가.
+                - high (float): 고가.
+                - low (float): 저가.
+                - close (float): 종가.
+                - volume (int): 거래량.
+                - value (float): 거래 대금.
+
+        Raises:
+            ValueError: 주어진 티커가 유효하지 않은 경우 발생.
+        """
+
+        def __period_to_gubn(period):
+            # D: 일간, W: 주간, M: 월간
+            if period == "D":
+                return "0"
+            elif period == "W":
+                return "1"
+            elif period == "M":
+                return "2"
+            else:
+                raise ValueError(f"Unsupported period: {period}")
+
+        ticker_info = get_ticker_info(ticker)
+        if ticker_info is None:
+            raise ValueError(f"Ticker {ticker} not found")
+
+        rows = []
+        fetching = True
+        exchange = self._exchange_to_code(ticker_info["exchange"].loc[ticker])
+        search_date = last_date
+
+        gubn = __period_to_gubn(period)
+        modp = "1" if adjusted else "0"
+
+        while fetching:
+            CallLimiter().wait_limit_rate(90, scope="overseas_daily")
+
+            r = self.stock_api.get_dailyprice(exchange, ticker, gubn, modp, search_date.strftime("%Y%m%d"))
+
+            page = []
+            next_last_date = None
+            for d in r["output2"]:
+                row = {
+                    "date": d["xymd"],
+                    "open": float(d["open"]),
+                    "high": float(d["high"]),
+                    "low": float(d["low"]),
+                    "close": float(d["clos"]),
+                    "volume": int(d["tvol"]),
+                    "value": d["tamt"],
+                }
+                page.append(row)
+                next_last_date = row["date"]
+
+            if len(page) == 0:
+                fetching = False
+                break
+
+            rows += page
+
+            search_date = next_last_date - dtm.timedelta(days=1)
+            if search_date <= first_date:
+                fetching = False
+                break
+
+        rows.reverse()
+
+        df = pd.DataFrame(rows).set_index("date")
+
+        return df.loc[first_date:last_date].copy()
+
     def get_today_minute_data(self, ticker: str) -> pd.DataFrame:
         """
         특정 티커의 시간별 거래 데이터를 조회하여 데이터프레임으로 반환합니다.
@@ -368,16 +464,10 @@ class KISSimpleOverseasStock:
         if ticker_info is None:
             raise ValueError(f"Ticker {ticker} not found")
 
-        exchange_to_code = {
-            "NYSE": "NSE",
-            "NASD": "NAS",
-            "AMEX": "AMS",
-        }
-
         rows = []
 
         r = self.stock_api.inquire_time_itemchartprice(
-            excd=exchange_to_code[ticker_info["exchange"].loc[ticker]],
+            excd=self._exchange_to_code(ticker_info["exchange"].loc[ticker]),
             symb=ticker,
         )
 
@@ -429,14 +519,8 @@ class KISSimpleOverseasStock:
         if ticker_info is None:
             raise ValueError(f"Ticker {ticker} not found")
 
-        exchange_to_code = {
-            "NYSE": "NSE",
-            "NASD": "NAS",
-            "AMEX": "AMS",
-        }
-
         r = self.stock_api.get_price(
-            exchange_to_code[ticker_info["exchange"].loc[ticker]],
+            self._exchange_to_code(ticker_info["exchange"].loc[ticker]),
             ticker,
         )
 
@@ -541,7 +625,7 @@ class KISSimpleOverseasStock:
 
     def _exchange_to_code(self, exchange: str) -> str:
         if exchange == "NYSE":
-            return "NSE"
+            return "NYS"
         elif exchange == "NASD":
             return "NAS"
         elif exchange == "AMEX":
@@ -739,7 +823,6 @@ class KISSimpleOverseasStock:
         Raises:
             ValueError: API 호출 중 문제가 발생할 경우 발생.
         """
-
         r = self.stock_api.inquire_ccnl(
             self.account_no,
             self.account_product_code,
@@ -753,6 +836,9 @@ class KISSimpleOverseasStock:
         output = r["output"]
         result = []
         for d in output:
+            order_kr_time = dtm.datetime.combine(d["dmst_ord_dt"], d["ord_tmd"], tzinfo=self.kst)
+            order_time = order_kr_time.astimezone(self.nyt)
+
             order = OverseasStockOrder(
                 order_no=d["odno"],
                 asset_code=d["pdno"],
@@ -761,7 +847,8 @@ class KISSimpleOverseasStock:
                 quantity=d["ft_ord_qty"],
                 filled_quantity=d["ft_ccld_qty"],
                 pending_quantity=d["nccs_qty"],
-                order_time=dtm.datetime.combine(d["dmst_ord_dt"], d["ord_tmd"]),
+                order_time=order_time,
+                order_kr_time=order_kr_time,
                 filled_price=d["ft_ccld_unpr3"],
                 current_price=self._get_cached_price(d["pdno"]),
                 is_pending=d["nccs_qty"] != 0,
@@ -801,11 +888,63 @@ class KISSimpleOverseasStock:
         else:
             return result
 
-    def get_today_order_history(self, to_frame: bool = False) -> List[OverseasStockOrder] | pd.DataFrame:
+    def get_today_order_history(self, target_date: Optional[dtm.date] = None, to_frame: bool = False) -> List[OverseasStockOrder] | pd.DataFrame:
         """
-        오늘의 주문 내역을 조회하여 리스트 또는 데이터프레임 형식으로 반환합니다.
+        현지 기준 오늘의 주문 내역을 조회하여 리스트 또는 데이터프레임 형식으로 반환합니다.
 
         Args:
+            target_date (dtm.date, optional): 조회할 현지 기준 날짜. 기본값은 None (오늘).
+            to_frame (bool, optional): True일 경우 Pandas DataFrame으로 반환, False일 경우 리스트 형식의 OverseasStockOrder 객체들로 반환. 기본값은 False.
+
+        Returns:
+            List[OverseasStockOrder] | pd.DataFrame: 현지 기준 오늘의 주문 내역 리스트 또는 DataFrame.
+                - 리스트 형식 (OverseasStockOrder 객체들):
+                    - order_no (str): 주문 번호.
+                    - asset_code (str): 자산 코드 (티커).
+                    - side (OrderSide): 매수(BUY) 또는 매도(SELL).
+                    - price (Decimal): 주문 가격.
+                    - quantity (int): 주문 수량.
+                    - filled_quantity (int): 체결된 수량.
+                    - pending_quantity (int): 대기 중인 수량.
+                    - order_time (datetime): 주문 시간. 현지 기준.
+                    - order_kr_time (datetime): 주문 시간. 한국 기준.
+                    - filled_price (Decimal): 체결 가격.
+                    - current_price (Decimal): 현재 가격.
+                    - is_pending (bool): 주문 대기 여부.
+                    - org_order_no (str): 원래 주문 번호 (수정/취소 주문의 경우).
+                    - order_type (str): 주문 유형 (초기값 None).
+                    - req_type (str): 주문 요청 유형 (정정/취소 등).
+                    - exchange (str): 거래소 코드.
+                    - currency (str): 거래 통화 코드.
+                - 데이터프레임 형식 (to_frame=True):
+                    - 주문 번호(order_no)를 인덱스로 한 Pandas DataFrame.
+                    - 나머지 필드는 위와 동일하며, 가격과 수량은 숫자 형식으로 변환됨.
+
+        Raises:
+            ValueError: API 호출 중 문제가 발생할 경우 발생.
+        """
+        if target_date is None:
+            tzinfo = ZoneInfo("America/New_York")
+            from_date = dtm.datetime.now(tzinfo).date()
+            to_date = from_date
+        else:
+            from_date = target_date
+            to_date = target_date
+
+        return self.get_order_history(from_date, to_date, to_frame)
+
+    def get_order_history(
+        self,
+        from_date: dtm.date,
+        to_date: dtm.date,
+        to_frame: bool = False,
+    ) -> List[OverseasStockOrder] | pd.DataFrame:
+        """
+        주문 내역을 조회하여 리스트 또는 데이터프레임 형식으로 반환합니다.
+
+        Args:
+            from_date (dtm.date): 조회를 시작할 날짜. (현지 기준)
+            to_date (dtm.date): 조회를 마칠 날짜. (현지 기준)
             to_frame (bool, optional): True일 경우 Pandas DataFrame으로 반환, False일 경우 리스트 형식의 OverseasStockOrder 객체들로 반환. 기본값은 False.
 
         Returns:
@@ -818,7 +957,8 @@ class KISSimpleOverseasStock:
                     - quantity (int): 주문 수량.
                     - filled_quantity (int): 체결된 수량.
                     - pending_quantity (int): 대기 중인 수량.
-                    - order_time (datetime): 주문 시간.
+                    - order_time (datetime): 주문 시간 (현지 기준).
+                    - order_kr_time (datetime): 주문 시간 (한국 기준).
                     - filled_price (Decimal): 체결 가격.
                     - current_price (Decimal): 현재 가격.
                     - is_pending (bool): 주문 대기 여부.
@@ -838,8 +978,8 @@ class KISSimpleOverseasStock:
         r = self.stock_api.inquire_ccnl(
             self.account_no,
             self.account_product_code,
-            dtm.date.today() - dtm.timedelta(days=1),
-            dtm.date.today(),
+            from_date,
+            to_date,
             "NASD",
             "%",
             "00",
@@ -849,6 +989,9 @@ class KISSimpleOverseasStock:
 
         result = []
         for d in output:
+            order_kr_time = dtm.datetime.combine(d["dmst_ord_dt"], d["ord_tmd"], tzinfo=self.kst)
+            order_time = order_kr_time.astimezone(self.nyt)
+
             order = OverseasStockOrder(
                 order_no=d["odno"],
                 asset_code=d["pdno"],
@@ -857,7 +1000,8 @@ class KISSimpleOverseasStock:
                 quantity=d["ft_ord_qty"],
                 filled_quantity=d["ft_ccld_qty"],
                 pending_quantity=d["nccs_qty"],
-                order_time=dtm.datetime.combine(d["dmst_ord_dt"], d["ord_tmd"]),
+                order_time=order_time,
+                order_kr_time=order_kr_time,
                 filled_price=d["ft_ccld_unpr3"],
                 current_price=self._get_cached_price(d["pdno"]),
                 is_pending=d["nccs_qty"] != 0,
@@ -979,7 +1123,7 @@ class KISSimpleOverseasStock:
 
         return {
             "order_no": r["output"]["ODNO"],
-            "date": dtm.date.today().strftime("%Y%m%d"),
+            "date": dtm.datetime.now(self.nyt).strftime("%Y%m%d"),
         }
 
     def cancel_scheduled_order(self, org_order_no: str, reservation_date: dtm.date):
@@ -988,7 +1132,7 @@ class KISSimpleOverseasStock:
 
         Args:
             org_order_no (str): 취소할 예약 주문의 주문 번호.
-            reservation_date (datetime.date): 예약 주문 접수 일자.
+            reservation_date (datetime.date): 예약 주문 접수 일자. 현지기준.
 
         Returns:
             str: 취소된 예약 주문 번호 (OVRS_RSVN_ODNO).
@@ -1017,8 +1161,8 @@ class KISSimpleOverseasStock:
         지정된 기간 동안의 예약 주문 목록을 조회합니다.
 
         Args:
-            start_date (datetime.date, optional): 조회할 시작 일자. 기본값은 당일.
-            end_date (datetime.date, optional): 조회할 종료 일자. 기본값은 당일.
+            start_date (datetime.date, optional): 현지 기준 조회할 시작 일자. 기본값은 당일.
+            end_date (datetime.date, optional): 현지 기준 조회할 종료 일자. 기본값은 당일.
             include_cancelled (bool, optional): 취소된 예약 주문을 포함할지 여부. 기본값은 False.
             to_frame (bool, optional): True일 경우 Pandas DataFrame으로 반환, False일 경우 리스트 형식의 dict 객체들로 반환. 기본값은 False.
 
@@ -1027,7 +1171,7 @@ class KISSimpleOverseasStock:
                 각 사전에는 다음과 같은 정보가 포함됩니다:
 
                 - is_cancelled (str): 주문 취소 여부.
-                - reservation_date (str): 예약 주문 접수 일자 (YYYYMMDD).
+                - reservation_date (str): 현지 기준 예약 주문 접수 일자 (YYYYMMDD).
                 - order_no (str): 해외 예약 주문 번호.
                 - asset_code (str): 자산 코드 (티커).
                 - order_date (str): 주문 일자 (YYYYMMDD).
@@ -1046,9 +1190,9 @@ class KISSimpleOverseasStock:
         """
 
         if start_date is None:
-            start_date = dtm.date.today()
+            start_date = dtm.datetime.now(self.nyt).date()
         if end_date is None:
-            end_date = dtm.date.today()
+            end_date = dtm.datetime.now(self.nyt).date()
 
         r = self.stock_api.order_resv_list(
             self.account_no,
@@ -1110,6 +1254,7 @@ class KISSimpleOverseasStock:
                 - ask_volume (int): 1차 매도 호가 잔량.
                 - bid_price (Decimal): 1차 매수 호가 가격.
                 - bid_volume (int): 1차 매수 호가 잔량.
+                - time (dtm.datetime): 현지 기준 호가 정보 조회 시간.
                 - bids (list): 매수 호가 목록 (각 항목은 price와 volume을 포함하는 dict).
                 - asks (list): 매도 호가 목록 (각 항목은 price과 volume을 포함하는 dict).
 
@@ -1138,7 +1283,7 @@ class KISSimpleOverseasStock:
             "ask_volume": o2["vask1"],
             "bid_price": o2["pbid1"],
             "bid_volume": o2["vbid1"],
-            "time": dtm.datetime.strptime(o1["dymd"] + o1["dhms"], "%Y%m%d%H%M%S"),
+            "time": dtm.datetime.strptime(o1["dymd"] + o1["dhms"], "%Y%m%d%H%M%S").astimezone(self.nyt),
             "bids": [{"price": o2[f"pbid{i}"], "volume": o2[f"vbid{i}"]} for i in range(1, 11)],
             "asks": [{"price": o2[f"pask{i}"], "volume": o2[f"vask{i}"]} for i in range(1, 11)],
         }
