@@ -6,12 +6,13 @@ from pyqqq.data.domestic import get_tickers
 from pyqqq.datatypes import *
 from pyqqq.utils.api_client import raise_for_status, send_request
 from pyqqq.utils.array import find
-from pyqqq.utils.logger import get_logger, logging
+from pyqqq.utils.logger import get_logger
 from pyqqq.utils.market_schedule import get_market_schedule
 from typing import Dict, Optional, List
 import asyncio
 import os
 import pyqqq.config as c
+import datetime as dtm
 
 
 class TradingTracker:
@@ -25,12 +26,12 @@ class TradingTracker:
         fee_rate (Decimal): 증권사 수수료율 (기본값: 0.015%)
     """
 
-    logger = get_logger("trading_tracker", level=logging.INFO)
+    logger = get_logger(__name__ + ".TradingTracker")
 
     def __init__(
         self,
         simple_api: EBestSimpleDomesticStock | KISSimpleDomesticStock,
-        fee_rate: Decimal = Decimal(0.00015),  # 뱅키스, LS증권 수수료율 0.015%
+        fee_rate: Decimal = Decimal("0.00015"),  # 뱅키스, LS증권 수수료율 0.015%
     ):
         self.positions: List[StockPosition] = []
         """ 보유 포지션 목록 """
@@ -64,6 +65,7 @@ class TradingTracker:
         self.tax_rate = Decimal("0.0018")  # KOSPI, KOSDAQ 매도시 거래세율 0.18%
         self.tickers: Dict[str, Dict] = {}  # 종목 코드별 종목 정보
         self.ticker_date: dtm.datetime = None  # 종목 정보 갱신 시간
+        self.save_trading_history = False  # 거래 내역 저장 여부
 
     async def start(self):
         """
@@ -77,7 +79,7 @@ class TradingTracker:
                 self.simple_api.account_no + self.simple_api.account_product_code
             )
 
-        self.logger.info(f"Trading tarcker started! Account No: {self.account_no}")
+        self.logger.info(f"Trading tarcker started! Account No: {self.account_no} / save history: {self.save_trading_history}")
 
         self._fetch_tickers()
         self._sync_positions_and_pending_orders()
@@ -94,6 +96,9 @@ class TradingTracker:
             asyncio.create_task(self._monitor_schedule()),
         ]
 
+    def enable_save_trading_history(self):
+        self.save_trading_history = True
+
     def _fetch_tickers(self):
         df = get_tickers(dtm.date.today())
         df.reset_index(inplace=True)
@@ -417,6 +422,9 @@ class TradingTracker:
         self._send_trading_history(data)
 
     def _send_trading_history(self, history: TradingHistory):
+        if not self.save_trading_history:
+            return
+
         url = f"{c.PYQQQ_API_URL}/analytics/trades/{history.order_no}"
 
         data = asdict(history)
@@ -441,6 +449,9 @@ class TradingTracker:
         self.logger.info(f"save trading history: {data}")
 
     def save_positions(self):
+        if not self.save_trading_history:
+            return
+
         strategy_name = os.getenv("STRATEGY_NAME")
         if strategy_name is None:
             return
