@@ -3,7 +3,7 @@ import pyqqq
 import requests
 
 
-@retry(requests.HTTPError)
+@retry((requests.HTTPError, requests.ConnectionError, requests.Timeout))
 def send_request(method: str, url: str, **kwargs):
     api_key = pyqqq.get_api_key()
     if not api_key:
@@ -13,6 +13,7 @@ def send_request(method: str, url: str, **kwargs):
         method=method,
         url=url,
         headers={"Authorization": f"Bearer {api_key}"},
+        timeout=30,
         **kwargs,
     )
 
